@@ -1,11 +1,11 @@
-from typing import Type
-from .storage import Storage
-from .pickle_storage import PickleStorage
+from typing import Literal, Type
 from .memory_storage import MemoryStorage
-from .bcolz_storage import BcolzStorage
+from .pickle_storage import PickleStorage
+from .storage import Storage
 
-STORAGE_MAP: dict[str, Type[Storage]] = {
+StorageType = Literal["pickle", "memory"]
+
+STORAGE_MAP: dict[StorageType, Type[Storage]] = {
   "pickle": PickleStorage,
   "memory": MemoryStorage,
-  "bcolz": BcolzStorage,
 }
