@@ -1,22 +1,26 @@
 import pickle
 import shutil
 from datetime import datetime
+from io import BytesIO
 from pathlib import Path
+from ..utils import clear_directory
 from .storage import Storage
 
+try:
+  import polars as pl
+except:
+  pl = None
+
 def filedate(path: Path) -> datetime:
   return datetime.fromtimestamp(path.stat().st_mtime)
 
-def empty_dirs(path: Path):
-  nonempty_count = 0
-  for child in path.iterdir():
-    nonempty_count += 1
-    if child.is_dir():
-      for grand_child in empty_dirs(child):
-        yield grand_child
-        nonempty_count -= child == grand_child
-  if nonempty_count == 0:
-    yield path
+class ExtendedPickler(pickle.Pickler):
+  def reducer_override(self, obj): # type: ignore
+    if pl and isinstance(obj, pl.DataFrame):
+      buffer = BytesIO()
+      obj.rechunk().write_parquet(buffer)
+      return pl.read_parquet, (buffer.getvalue(),)
+    return NotImplemented
 
 class PickleStorage(Storage):
   def get_path(self, call_hash: str):
@@ -26,7 +30,7 @@ class PickleStorage(Storage):
     path = self.get_path(call_hash)
     path.parent.mkdir(parents=True, exist_ok=True)
     with path.open("wb") as file:
-      pickle.dump(data, file, -1)
+      ExtendedPickler(file, -1).dump(data)
     return data
 
   def exists(self, call_hash):
@@ -58,11 +62,7 @@ class PickleStorage(Storage):
           count += 1
           pkl_path.unlink(missing_ok=True)
       print(f"Removed {count} expired checkpoints for {self.cached_fn.__qualname__}")
-    if fn_path.exists():
-      for file in fn_path.glob("**/.DS_Store"):
-        file.unlink()
-      for directory in empty_dirs(fn_path):
-        directory.rmdir()
+    clear_directory(fn_path)
 
   def clear(self):
     fn_path = self.fn_dir().parent
